##  Connecting SAP LeanIX to the SAP Cloud ALM API
To connect SAP LeanIX to SAP Cloud ALM API, do the following:
  1. In the administration area of SAP LeanIX, navigate to the Integrations section.
  2. Click Add Integrations.
  3. Locate SAP Cloud ALM for Managing Projects and click Configure.
  4. Download the service key from the SAP BTP cockpit that you previously created and input it under Authenticate via API.
  5. Click Save.


![Connecting SAP LeanIX to the SAP Cloud ALM API](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e01be7a441014b8f9db5b87073412_LowRes.png)
Connecting SAP LeanIX to the SAP Cloud ALM API
